@@ -169,30 +169,27 @@ class DIP(BaseModel):
                     self.env.nodes.append(node)
         # Validate nodes
         for node in self.env.nodes:
-            # Check if all declared nodes have assigned value
-            if node.defined and node.value is None and not self.env.docs:
-                raise Exception(f"Node value must be defined:", node.code)
-            # check if node value is in options
-            if node.keyword!='bool' and node.options:
-                if node.value not in node.options:
-                    if isinstance(node.value, Type):
-                        raise Exception(f"Value '{str(node.value)}' of node '{node.name}' doesn't match with any option:", node.options)
-                    elif not self.env.docs:
-                        raise Exception(f"Value '{node.value}' of node '{node.name}' doesn't match with any option:", node.options)
-            # Check conditions
-            if node.keyword in ['float','int'] and node.condition and not self.env.docs:
-                env=self.env.copy()
-                env.autoref = node.name
-                with LogicalSolver(env) as s:
-                    if not s.solve(node.condition):
-                        raise Exception("Node does not fullfil a condition:",
-                                        node.name, node.condition)
-            # Check formats if set for strings
-            if node.keyword=='str' and node.format:
-                m = re.match(node.format, node.value.value)
-                if not m:
-                    raise Exception("Node value does not match the format:",
-                                    node.value.value, node.format)
+            if not self.env.docs:
+                # Check if all declared nodes have assigned value
+                if node.defined and node.value is None:
+                    raise Exception(f"Node value must be defined:", node.code)
+                # check if node value is in options
+                if isinstance(node,(IntegerNode, FloatNode, StringNode)):
+                    node.validate_options()
+                # Check conditions
+                if node.keyword in ['float','int'] and node.condition:
+                    env=self.env.copy()
+                    env.autoref = node.name
+                    with LogicalSolver(env) as s:
+                        if not s.solve(node.condition):
+                            raise Exception("Node does not fullfil a condition:",
+                                            node.name, node.condition)
+                # Check formats if set for strings
+                if node.keyword=='str' and node.format:
+                    m = re.match(node.format, node.value.value)
+                    if not m:
+                        raise Exception("Node value does not match the format:",
+                                        node.value.value, node.format)
         return self.env
         
     def _determine_node(self, line):
