@@ -159,20 +159,3 @@ class Node(NodeBase):
             if not node.units_raw:
                 node.units_raw = nodes[0].units_raw
         
-    def set_option(self, node, env):
-        """ Set option using value of a different node
-        """
-        if self.options is not None:
-            node.set_value(self.cast_value(node.value_raw))
-            if self.keyword=='int':
-                node.value = IntegerType(node.value, node.units_raw)
-                if not env.docs:
-                    node.value.convert(self.units_raw, env)
-            elif self.keyword=='float':
-                node.value = FloatType(node.value, node.units_raw)
-                if not env.docs:
-                    node.value.convert(self.units_raw, env)
-            self.options.append(node.value)
-        else:
-            raise Exception(f"Node '{self.keyword}' does not support options")
-                                                 
