@@ -2,10 +2,11 @@ from typing import List
 from pydantic import BaseModel
 
 from .DIP_Node import Node
+from .DIP_NodeSelect import NodeSelect
 from ..solvers import UnitSolver, NumericalSolver, FunctionSolver
 from ..datatypes import FloatType, IntegerType
 
-class FloatNode(Node):
+class FloatNode(Node, NodeSelect):
     keyword: str = 'float'
     value: float = None
     options: List[BaseModel] = []
