@@ -3,10 +3,11 @@ from pydantic import BaseModel
 import numpy as np
 
 from .DIP_Node import Node
+from .DIP_NodeSelect import NodeSelect
 from ..datatypes import IntegerType,FloatType
 from ..solvers import UnitSolver, NumericalSolver, FunctionSolver
 
-class IntegerNode(Node):
+class IntegerNode(Node, NodeSelect):
     keyword: str = 'int'
     value: int = None
     options: List[BaseModel] = []
