@@ -1,4 +1,7 @@
 from .DIP_Node import Node
+from .DIP_Node_Integer import IntegerNode
+from .DIP_Node_Float import FloatNode
+from .DIP_Node_String import StringNode
 
 class OptionNode(Node):
     keyword: str = 'option'
@@ -19,6 +22,9 @@ class OptionNode(Node):
             return OptionNode(parser)
         
     def parse(self, env):
+        node = env.nodes[-1]
+        if not isinstance(node,(IntegerNode,FloatNode,StringNode)):
+            raise Exception(f"Node '{env.nodes[-1].keyword}' does not support options")
         if self.dimension:
             for value in self.cast_value():
                 self.value_raw = value
