@@ -1,13 +1,10 @@
-from typing import List
-from pydantic import BaseModel
-
 from .DIP_Node import Node
+from .DIP_NodeSelect import NodeSelect
 from ..solvers import TemplateSolver, FunctionSolver
 from ..datatypes import StringType
 
-class StringNode(Node):
+class StringNode(Node, NodeSelect):
     keyword: str = 'str'
-    options: List[BaseModel] = []
     format: str = None
 
     @staticmethod
